@@ -31,6 +31,8 @@ function _odl_show_info {
         sudo ovs-ofctl --protocols OpenFlow13 dump-ports $br
         sudo ovs-ofctl --protocols OpenFlow13 dump-ports-desc $br
         sudo ovs-ofctl --protocols OpenFlow13 dump-flows $br
+        sudo ovs-ofctl --protocols OpenFlow13 dump-groups $br
+        sudo ovs-ofctl --protocols OpenFlow13 dump-group-stats $br
     done
 
     openstack network list
@@ -43,12 +45,20 @@ function _odl_show_info {
     # ODL_MGR_HOST=$SERVICE_HOST
     # ODL_PORT=8087
     # There is no good way to retrieve from setting.odl at the moment
-    curl --silent --user admin:admin "http://localhost:8087/restconf/config/neutron:neutron?prettyPrint=true"
-    echo -e "\n"
+    local PATHES="config/neutron:neutron config/opendaylight-inventory:nodes config/elan:elan-instances config/elan:elan-interfaces"
+    for path in $PATHES; do
+        echo "path=${path}"
+        curl --silent --user admin:admin "http://localhost:8087/restconf/${path}?prettyPrint=true"
+        echo
+    done
+
+    echo
+    echo
 }
 
 echo "Some pre-process info"
 _odl_show_info
+$BASE/new/opendaylight/*karaf-*/bin/client "feature:list -i"
 
 echo "Running networking-odl test suite"
 set +e
@@ -59,4 +69,8 @@ set -e
 echo "Some post-process info"
 _odl_show_info
 
+# stop ODL server for complete log
+$BASE/new/opendaylight/*karaf-*/bin/stop
+sleep 3
+
 return $retval
