@@ -7,11 +7,15 @@ GATE_DEST=$BASE/new
 DEVSTACK_PATH=$GATE_DEST/devstack
 # for localrc_set
 source $DEVSTACK_PATH/inc/ini-config
+source $GATE_DEST/networking-odl/devstack/functions
 
 case "$ODL_RELEASE_BASE" in
     latest-snapshot)
         ODL_RELEASE=latest-snapshot
         ;;
+    oxygen-snapshot)
+        ODL_RELEASE=oxygen-snapshot-0.8
+        ;;
     nitrogen-snapshot)
         ODL_RELEASE=nitrogen-snapshot-0.7
         ;;
@@ -19,7 +23,9 @@ case "$ODL_RELEASE_BASE" in
         ODL_RELEASE=carbon-snapshot-0.6
         ;;
     boron-snapshot)
-        ODL_RELEASE=boron-snapshot-0.5
+        # NOTE(yamahata): boron release ends by SR4. no more snapshot
+        # https://wiki.opendaylight.org/view/Simultaneous_Release:Boron_Release_Plan
+        ODL_RELEASE=boron-0.5.4-SR4
         ;;
     *)
         echo "Unknown ODL release base: $ODL_RELEASE_BASE"
@@ -42,7 +48,7 @@ esac
 ODL_PORT_BINDING_CONTROLLER=pseudo-agentdb-binding
 
 ODL_GATE_SERVICE_PROVIDER=${ODL_GATE_SERVICE_PROVIDER%-}
-if [[ -z "$ODL_GATE_SERVICE_PROVIDER" ]] && [[ -n "${RALLY_SCENARIO}" ]]; then
+if [[ -z "$ODL_GATE_SERVICE_PROVIDER" ]]; then
     ODL_GATE_SERVICE_PROVIDER=vpnservice
 fi
 
@@ -112,18 +118,5 @@ localrc_set $localrc_file "RALLY_SCENARIO" "${RALLY_SCENARIO}"
 # https://bugs.opendaylight.org/show_bug.cgi?id=7456
 # https://bugs.opendaylight.org/show_bug.cgi?id=8133
 if [[ "$DEVSTACK_GATE_TOPOLOGY" == "multinode" ]] || [[ "$ODL_GATE_SERVICE_PROVIDER" == "vpnservice" ]]; then
-    cat <<EOF >> $DEVSTACK_PATH/local.sh
-#!/usr/bin/env bash
-
-sudo ifconfig br-ex 172.24.5.1/24 up
-source $DEVSTACK_PATH/openrc admin
-openstack router unset --external-gateway router1
-openstack port list --router router1 -c ID -f value | xargs -I {} openstack router remove port router1 {}
-openstack router delete router1
-openstack subnet list | grep -e public -e private | cut -f2 -d'|' | xargs openstack subnet delete
-openstack network list | grep -e public -e private | cut -f2 -d'|' | xargs openstack network delete
-openstack network create public --external --provider-network-type=flat --provider-physical-network=public
-openstack subnet create --network=public --subnet-range=172.24.5.0/24 --gateway 172.24.5.1 public-subnet
-EOF
-    chmod 755 $DEVSTACK_PATH/local.sh
+    purge_and_recreate_initial_networks $DEVSTACK_PATH
 fi
