@@ -57,20 +57,17 @@ Examples:
 
 import os
 import socket
-import subprocess
+import subprocess  # nosec
 import sys
 
 from oslo_config import cfg
-from oslo_log import log
+from oslo_log import log as logging
 from oslo_serialization import jsonutils
 
 from networking_odl._i18n import _
-from networking_odl._i18n import _LE
-from networking_odl._i18n import _LI
-from networking_odl._i18n import _LW
 
 
-LOG = log.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 USERSPACE_DATAPATH_TYPES = ['netdev', 'dpdkvhostuser']
 
@@ -78,7 +75,7 @@ COMMAND_LINE_OPTIONS = [
 
     cfg.ListOpt(
         'allowed_network_types',
-        default=['local', 'vlan', 'vxlan', 'gre'],
+        default=['local', 'flat', 'vlan', 'vxlan', 'gre'],
         help=_("""
             Specifies allowed network types given as a Comma-separated list of
             types.
@@ -125,15 +122,6 @@ COMMAND_LINE_OPTIONS = [
                      --datapath_type=system         # in all other cases
             """)),
 
-    cfg.BoolOpt(
-        'debug',
-        default=False,
-        help=_("""
-            It shows debugging informations.
-
-            Default: --nodebug
-            """)),
-
     cfg.StrOpt(
         'host',
         default=socket.gethostname(),  # pylint: disable=no-member
@@ -171,6 +159,19 @@ COMMAND_LINE_OPTIONS = [
             Default:
             """)),
 
+    cfg.BoolOpt(
+        'ovs_sriov_offload',
+        default=None,
+        help=_("""
+            It adds SR-IOV virtual interface support to allow ovs hardware
+            offload.
+
+            NOTE: This feature should be used with ovs>=2.8.0 and SR-IOV NIC
+            which support switchdev mode and tc offload.
+
+            Default:
+            """)),
+
     cfg.StrOpt(
         'ovs_hostconfigs',
         help=_("""
@@ -245,9 +246,6 @@ COMMAND_LINE_OPTIONS = [
 ]
 
 
-DEFAULT_COMMAND_LINE_OPTIONS = tuple(sys.argv[1:])
-
-
 def set_ovs_extid_hostconfigs(conf, ovs_vsctl):
     if conf.ovs_hostconfigs:
         json_str = conf.ovs_hostconfigs.replace("\'", "\"")
@@ -282,7 +280,7 @@ def _hostconfigs_from_conf(conf, uuid, userspace_datapath_types):
     vif_details = _vif_details_from_conf(
         conf=conf, uuid=uuid, vif_type=vif_type)
 
-    return {
+    host_config = {
         "ODL L2": {
             "allowed_network_types": conf.allowed_network_types,
             "bridge_mappings": conf.bridge_mappings,
@@ -292,10 +290,18 @@ def _hostconfigs_from_conf(conf, uuid, userspace_datapath_types):
                     "vif_details": vif_details,
                     "vif_type": vif_type,
                     "vnic_type": "normal",
-                }
+                },
             ]
         }
     }
+    if vif_type == 'ovs' and conf.ovs_sriov_offload:
+        direct_vnic = {
+            "vif_details": vif_details,
+            "vif_type": vif_type,
+            "vnic_type": "direct",
+        }
+        host_config["ODL L2"]["supported_vnic_types"].append(direct_vnic)
+    return host_config
 
 
 def _vif_type_from_conf(conf, userspace_datapath_types):
@@ -305,9 +311,9 @@ def _vif_type_from_conf(conf, userspace_datapath_types):
         # take it from  datapath_type
         if conf.datapath_type in USERSPACE_DATAPATH_TYPES:
             if conf.datapath_type not in userspace_datapath_types:
-                LOG.warning(_LW(
+                LOG.warning(
                     "Using user space data path type '%s' even if no "
-                    "support was detected."), conf.datapath_type)
+                    "support was detected.", conf.datapath_type)
             return 'vhostuser'
         else:
             return 'ovs'
@@ -317,7 +323,7 @@ def _vif_type_from_conf(conf, userspace_datapath_types):
         if userspace_datapath_types:
             return 'vhostuser'
 
-        raise ValueError(_LE(
+        raise ValueError(_(
             "--ovs_dpdk option was specified but the 'netdev' datapath_type "
             "was not enabled. "
             "To override use option --datapath_type=netdev"))
@@ -328,23 +334,23 @@ def _vif_type_from_conf(conf, userspace_datapath_types):
     # take detected dtype -------------------------------------------------
     if userspace_datapath_types:
         return 'vhostuser'
-    else:
-        return 'ovs'
+
+    return 'ovs'
 
 
 def _vif_details_from_conf(conf, uuid, vif_type):
-    host_addrasses = [conf.local_ip or conf.host]
+    host_addresses = [conf.local_ip or conf.host]
     if vif_type == 'ovs':
         # OVS legacy mode
         return {"uuid": uuid,
-                "host_addresses": host_addrasses,
+                "host_addresses": host_addresses,
                 "has_datapath_type_netdev": False,
                 "support_vhost_user": False}
 
     elif vif_type == 'vhostuser':
         # enable VHOSTUSER
         return {"uuid": uuid,
-                "host_addresses": host_addrasses,
+                "host_addresses": host_addresses,
                 "has_datapath_type_netdev": True,
                 "support_vhost_user": True,
                 "port_prefix": conf.vhostuser_port_prefix,
@@ -353,16 +359,18 @@ def _vif_details_from_conf(conf, uuid, vif_type):
                 "vhostuser_mode": conf.vhostuser_mode,
                 "vhostuser_socket": os.path.join(
                     conf.vhostuser_socket_dir,
-                    conf.vhostuser_port_prefix + '$PORTID')}
+                    conf.vhostuser_port_prefix + '$PORT_ID')}
+    raise ValueError(_("vif type: '%s' not supported") % vif_type)
 
 
-def setup_conf(args=None):
+def setup_conf(args):
     """setup cmdline options."""
-
-    if args is None:
-        args = DEFAULT_COMMAND_LINE_OPTIONS
-
     conf = cfg.ConfigOpts()
+    # NOTE, Logging options must be registered before parsing cli
+    # options, refer:-
+    # https://docs.openstack.org/oslo.log/latest/user/usage.html#oslo-logging-setup-methods
+    logging.register_options(conf)
+
     if '-h' in args or '--help' in args:
         # Prints out script documentation."
         print(__doc__)
@@ -440,32 +448,47 @@ class OvsVsctl(object):
         self._set(record=self.uuid(), value=value)
 
     def _get(self, record, name):
-        return self._excute('get', self.TABLE, record, name)
+        return self._execute('get', self.TABLE, record, name)
 
     def _set(self, record, value):
-        self._excute('set', self.TABLE, record, value)
+        self._execute('set', self.TABLE, record, value)
 
-    def _excute(self, *args):
+    def _execute(self, *args):
         command_line = (self.COMMAND,) + args
         LOG.info(
-            _LI("SET-HOSTCONFIGS: Executing cmd: %s"), ' '.join(command_line))
-        return subprocess.check_output(command_line).strip()
+            "SET-HOSTCONFIGS: Executing cmd: %s", ' '.join(command_line))
+        return subprocess.check_output(command_line).strip()  # nosec
+
+
+def setup_logging(conf):
+    # NOTE, Hacky way to enable logging. oslo log needs other parameters also
+    # to register, but neutron.conf is not present on compute node therefore
+    # we can not dependant on it. However, nova-compute is present on compute
+    # node, so code can depend on oslo log
+    # if script does not have write permission in the directory then
+    # stack trace appear on console.
+    logging.setup(conf, 'networking-odl')
+    LOG.info("Logging enabled!")
 
 
 def main(args=None):
     """Main."""
 
+    if args is None:
+        args = sys.argv[1:]
+
     conf = setup_conf(args)
+    setup_logging(conf)
 
     if os.geteuid() != 0:
-        LOG.error(_LE('Root permissions are required to configure ovsdb.'))
+        LOG.error('Root permissions are required to configure ovsdb.')
         return 1
 
     try:
         set_ovs_extid_hostconfigs(conf=conf, ovs_vsctl=OvsVsctl())
 
     except Exception as ex:  # pylint: disable=broad-except
-        LOG.error(_LE("Fatal error: %s"), ex, exc_info=conf.debug)
+        LOG.error("Fatal error: %s", ex, exc_info=conf.debug)
         return 1
 
     else:
