@@ -13,14 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import threading
+
 from oslo_config import cfg
 from oslo_log import log
 from oslo_serialization import jsonutils
 from oslo_utils import excutils
 import requests
-import threading
+from requests import sessions
 
-from networking_odl._i18n import _LE
 from networking_odl.common import constants as odl_const
 from networking_odl.common import utils
 
@@ -44,7 +45,7 @@ class OpenDaylightRestClient(object):
             LOG.debug("ODL lightweight testing is enabled, "
                       "returning a OpenDaylightLwtClient instance")
 
-            """Have to import at here, otherwise we create a dependency loop"""
+            # Have to import at here, otherwise we create a dependency loop
             from networking_odl.common import lightweight_testing as lwt
             cls = lwt.OpenDaylightLwtClient
 
@@ -57,9 +58,11 @@ class OpenDaylightRestClient(object):
             cfg.CONF.ml2_odl.timeout)
 
     def __init__(self, url, username, password, timeout):
+        super(OpenDaylightRestClient, self).__init__()
         self.url = url
         self.timeout = timeout
-        self.auth = (username, password)
+        self.session = sessions.Session()
+        self.session.auth = (username, password)
 
     def get_resource(self, resource_type, resource_id):
         response = self.get(utils.make_url_object(resource_type) + '/' +
@@ -67,7 +70,7 @@ class OpenDaylightRestClient(object):
         if response.status_code == requests.codes.not_found:
             return None
 
-        return self._check_rensponse(response).json()
+        return self._check_response(response).json()
 
     def get(self, urlpath='', data=None):
         return self.request('get', urlpath, data)
@@ -84,21 +87,20 @@ class OpenDaylightRestClient(object):
         LOG.debug(
             "Sending METHOD (%(method)s) URL (%(url)s) JSON (%(data)s)",
             {'method': method, 'url': url, 'data': data})
-        return requests.request(
-            method, url=url, headers=headers, data=data, auth=self.auth,
-            timeout=self.timeout)
+        return self.session.request(
+            method, url=url, headers=headers, data=data, timeout=self.timeout)
 
     def sendjson(self, method, urlpath, obj):
         """Send json to the OpenDaylight controller."""
         data = jsonutils.dumps(obj, indent=2) if obj else None
         try:
-            return self._check_rensponse(
+            return self._check_response(
                 self.request(method, urlpath, data))
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.error(_LE("REST request ( %(method)s ) to "
-                              "url ( %(urlpath)s ) is failed."
-                              "Request body : [%(body)s] service"),
+                LOG.error("REST request ( %(method)s ) to "
+                          "url ( %(urlpath)s ) is failed. "
+                          "Request body : [%(body)s] service",
                           {'method': method,
                            'urlpath': urlpath,
                            'body': obj})
@@ -120,26 +122,26 @@ class OpenDaylightRestClient(object):
         self.sendjson(method, urlpath, {object_type: data})
 
     def try_delete(self, urlpath):
-        rensponse = self.delete(urlpath)
-        if rensponse.status_code == requests.codes.not_found:
+        response = self.delete(urlpath)
+        if response.status_code == requests.codes.not_found:
             # The resource is already removed. ignore 404 gracefully
             LOG.debug("%(urlpath)s doesn't exist", {'urlpath': urlpath})
             return False
-        else:
-            self._check_rensponse(rensponse)
-            return True
 
-    def _check_rensponse(self, rensponse):
+        self._check_response(response)
+        return True
+
+    def _check_response(self, response):
         try:
-            rensponse.raise_for_status()
+            response.raise_for_status()
         except requests.HTTPError as error:
             with excutils.save_and_reraise_exception():
                 LOG.debug("Exception from ODL: %(e)s %(text)s",
-                          {'e': error, 'text': rensponse.text}, exc_info=1)
+                          {'e': error, 'text': response.text}, exc_info=1)
         else:
             LOG.debug("Got response:\n"
-                      "(%(response)s)", {'response': rensponse.text})
-            return rensponse
+                      "(%(response)s)", {'response': response.text})
+            return response
 
 
 class OpenDaylightRestClientGlobal(object):
