@@ -18,6 +18,8 @@ from oslo_config import cfg
 from networking_odl._i18n import _
 
 
+# TODO(mkolesni): Remove V2 notes from messages once V1 driver is removed
+# from the tree.
 odl_opts = [
     cfg.StrOpt('url',
                help=_("HTTP URL of OpenDaylight REST interface.")),
@@ -29,20 +31,23 @@ odl_opts = [
                help=_("HTTP timeout in seconds.")),
     cfg.IntOpt('session_timeout', default=30,
                help=_("Tomcat session timeout in minutes.")),
-    cfg.IntOpt('sync_timeout', default=10,
-               help=_("(V2 driver) Sync thread timeout in seconds.")),
+    cfg.FloatOpt('sync_timeout', default=10,
+                 help=_("(V2 driver) Sync thread timeout in seconds "
+                        "or fraction.")),
     cfg.IntOpt('retry_count', default=5,
                help=_("(V2 driver) Number of times to retry a row "
                       "before failing.")),
     cfg.IntOpt('maintenance_interval', default=300,
                help=_("(V2 driver) Journal maintenance operations interval "
                       "in seconds.")),
-    cfg.IntOpt('completed_rows_retention', default=600,
-               help=_("(V2 driver) Time to keep completed rows in seconds."
-                      "Completed rows retention will be checked every "
-                      "maintenance_interval by the cleanup thread."
-                      "To disable completed rows deletion "
-                      "value should be -1")),
+    cfg.IntOpt('completed_rows_retention', default=0,
+               help=_("(V2 driver) Time to keep completed rows (in seconds)."
+                      "For performance reasons it's not recommended to "
+                      "change this from the default value (0) which "
+                      "indicates completed rows aren't kept."
+                      "This value will be checked every maintenance_interval "
+                      "by the cleanup thread. To keep completed rows "
+                      "indefinitely, set the value to -1")),
     cfg.BoolOpt('enable_lightweight_testing',
                 default=False,
                 help=_('Test without real ODL.')),
