@@ -61,7 +61,8 @@ def _generate_subnet_deps(data):
 
 
 def _generate_port_deps(data):
-    object_ids = [fixed_ip['subnet_id'] for fixed_ip in data['fixed_ips']]
+    object_ids = set(fixed_ip['subnet_id'] for fixed_ip in data['fixed_ips'])
+    object_ids = list(object_ids)
     object_ids.append(data['network_id'])
     qos_policy_id = data.get('qos_policy_id')
     if qos_policy_id is not None:
@@ -131,15 +132,12 @@ def _generate_sfc_port_pair_deps(data):
 
 
 def _generate_sfc_port_pair_group_deps(data):
-    port_pairs = [port_pair['id'] for port_pair in data['port_pairs']]
-    return port_pairs
+    return data['port_pairs']
 
 
 def _generate_sfc_port_chain_deps(data):
-    object_ids = [port_pair_group['id'] for port_pair_group in
-                  data['port_pair_groups']]
-    flow_classifiers = [flow_classifier['id'] for flow_classifier in
-                        data['flow_classifiers']]
+    object_ids = data['port_pair_groups'][:]
+    flow_classifiers = data['flow_classifiers'][:]
     object_ids.extend(flow_classifiers)
 
     return object_ids
