@@ -21,8 +21,9 @@ from oslo_log import log as logging
 
 from networking_l2gw.services.l2gateway.common import constants
 from networking_l2gw.services.l2gateway import service_drivers
-from networking_odl._i18n import _LI
 from networking_odl.common import constants as odl_const
+from networking_odl.common import postcommit
+from networking_odl.journal import full_sync
 from networking_odl.journal import journal
 
 
@@ -30,9 +31,15 @@ cfg.CONF.import_group('ml2_odl', 'networking_odl.common.config')
 
 LOG = logging.getLogger(__name__)
 
+L2GW_RESOURCES = {
+    odl_const.ODL_L2GATEWAY: odl_const.ODL_L2GATEWAYS,
+    odl_const.ODL_L2GATEWAY_CONNECTION: odl_const.ODL_L2GATEWAY_CONNECTIONS
+}
 
+
+@postcommit.add_postcommit('l2_gateway', 'l2_gateway_connection')
 class OpenDaylightL2gwDriver(service_drivers.L2gwDriver):
-    """Opendaylight L2Gateway Service Driver
+    """OpenDaylight L2Gateway Service Driver
 
     This code is the openstack driver for exciting the OpenDaylight L2GW
     facility.
@@ -41,8 +48,9 @@ class OpenDaylightL2gwDriver(service_drivers.L2gwDriver):
     def __init__(self, service_plugin, validator=None):
         super(OpenDaylightL2gwDriver, self).__init__(service_plugin, validator)
         self.service_plugin = service_plugin
-        self.journal = journal.OpendaylightJournalThread()
-        LOG.info(_LI("ODL: Started OpenDaylight L2Gateway V2 driver"))
+        self.journal = journal.OpenDaylightJournalThread()
+        full_sync.register(constants.L2GW, L2GW_RESOURCES)
+        LOG.info("ODL: Started OpenDaylight L2Gateway V2 driver")
 
     @property
     def service_type(self):
@@ -50,19 +58,19 @@ class OpenDaylightL2gwDriver(service_drivers.L2gwDriver):
 
     @log_helpers.log_method_call
     def create_l2_gateway_precommit(self, context, l2_gateway):
-        journal.record(context, None, odl_const.ODL_L2GATEWAY,
+        journal.record(context, odl_const.ODL_L2GATEWAY,
                        l2_gateway['id'], odl_const.ODL_CREATE,
                        l2_gateway)
 
     @log_helpers.log_method_call
     def update_l2_gateway_precommit(self, context, l2_gateway):
-        journal.record(context, None, odl_const.ODL_L2GATEWAY,
+        journal.record(context, odl_const.ODL_L2GATEWAY,
                        l2_gateway['id'], odl_const.ODL_UPDATE,
                        l2_gateway)
 
     @log_helpers.log_method_call
     def delete_l2_gateway_precommit(self, context, l2_gateway_id):
-        journal.record(context, None, odl_const.ODL_L2GATEWAY,
+        journal.record(context, odl_const.ODL_L2GATEWAY,
                        l2_gateway_id, odl_const.ODL_DELETE,
                        l2_gateway_id)
 
@@ -73,7 +81,7 @@ class OpenDaylightL2gwDriver(service_drivers.L2gwDriver):
         odl_l2_gateway_connection['gateway_id'] = (
             l2_gateway_connection['l2_gateway_id'])
         odl_l2_gateway_connection.pop('l2_gateway_id')
-        journal.record(context, None, odl_const.ODL_L2GATEWAY_CONNECTION,
+        journal.record(context, odl_const.ODL_L2GATEWAY_CONNECTION,
                        odl_l2_gateway_connection['id'],
                        odl_const.ODL_CREATE,
                        odl_l2_gateway_connection)
@@ -81,32 +89,7 @@ class OpenDaylightL2gwDriver(service_drivers.L2gwDriver):
     @log_helpers.log_method_call
     def delete_l2_gateway_connection_precommit(self, context,
                                                l2_gateway_connection_id):
-        journal.record(context, None, odl_const.ODL_L2GATEWAY_CONNECTION,
+        journal.record(context, odl_const.ODL_L2GATEWAY_CONNECTION,
                        l2_gateway_connection_id,
                        odl_const.ODL_DELETE,
                        l2_gateway_connection_id)
-
-    def _postcommit(self, context):
-        self.journal.set_sync_event()
-
-    @log_helpers.log_method_call
-    def create_l2_gateway_postcommit(self, context, l2_gateway):
-        self._postcommit(context)
-
-    @log_helpers.log_method_call
-    def delete_l2_gateway_postcommit(self, context, l2_gateway_id):
-        self._postcommit(context)
-
-    @log_helpers.log_method_call
-    def update_l2_gateway_postcommit(self, context, l2_gateway):
-        self._postcommit(context)
-
-    @log_helpers.log_method_call
-    def create_l2_gateway_connection_postcommit(self, context,
-                                                l2_gateway_connection):
-        self._postcommit(context)
-
-    @log_helpers.log_method_call
-    def delete_l2_gateway_connection_postcommit(self, context,
-                                                l2_gateway_connection_id):
-        self._postcommit(context)
