@@ -14,6 +14,9 @@
 #  under the License.
 #
 
+from debtcollector import removals
+from neutron_lib import constants as q_const
+from neutron_lib.plugins import constants as plugin_constants
 from oslo_config import cfg
 from oslo_log import log as logging
 
@@ -26,10 +29,9 @@ from neutron.db import extraroute_db
 from neutron.db import l3_agentschedulers_db
 from neutron.db import l3_dvr_db
 from neutron.db import l3_gwmode_db
-from neutron_lib import constants as q_const
-from neutron_lib.plugins import constants as plugin_constants
 
 from networking_odl.common import client as odl_client
+from networking_odl.common import filters as odl_filters
 from networking_odl.common import utils as odl_utils
 
 
@@ -39,6 +41,9 @@ ROUTERS = 'routers'
 FLOATINGIPS = 'floatingips'
 
 
+@removals.removed_class(
+    'OpenDaylightL3RouterPlugin', version='Queens', removal_version='Rocky',
+    message="Usage of V1 drivers is deprecated. Please use V2 instead.")
 class OpenDaylightL3RouterPlugin(
         common_db_mixin.CommonDbMixin,
         extraroute_db.ExtraRoute_db_mixin,
@@ -82,6 +87,11 @@ class OpenDaylightL3RouterPlugin(
         """Filter out router attributes for an update operation."""
         odl_utils.try_del(router, ['id', 'tenant_id', 'status'])
 
+    def filter_disassociate_floatingip_attributes(self, fip_dict):
+        """Filter out floatingip attributes for an disassociate operation."""
+        odl_filters._filter_unmapped_null(
+            fip_dict, ['port_id', 'fixed_ip_address', 'router_id'])
+
     def create_router(self, context, router):
         router_dict = super(OpenDaylightL3RouterPlugin, self).create_router(
             context, router)
@@ -135,6 +145,23 @@ class OpenDaylightL3RouterPlugin(
         url = FLOATINGIPS + "/" + id
         self.client.sendjson('delete', url, None)
 
+    def disassociate_floatingips(self, context, port_id, do_notify=True):
+        fip_dicts = self.get_floatingips(context,
+                                         filters={'port_id': [port_id]})
+        router_ids = super(OpenDaylightL3RouterPlugin,
+                           self).disassociate_floatingips(context,
+                                                          port_id,
+                                                          do_notify)
+        for fip_dict in fip_dicts:
+            fip_dict = self.get_floatingip(context, fip_dict['id'])
+            fip_dict['status'] = q_const.FLOATINGIP_STATUS_DOWN
+            self.update_floatingip_status(context, fip_dict['id'],
+                                          fip_dict['status'])
+            self.filter_disassociate_floatingip_attributes(fip_dict)
+            url = FLOATINGIPS + "/" + fip_dict['id']
+            self.client.sendjson('put', url, {FLOATINGIPS[:-1]: fip_dict})
+        return router_ids
+
     dvr_deletens_if_no_port_warned = False
 
     def dvr_deletens_if_no_port(self, context, port_id):
