@@ -16,23 +16,24 @@
 import abc
 import copy
 
+from debtcollector import removals
 import six
 
 import netaddr
+from neutron_lib.api.definitions import allowedaddresspairs as addr_apidef
+from neutron_lib.api.definitions import multiprovidernet as mpnet_apidef
 from neutron_lib.api.definitions import provider_net as providernet
 from neutron_lib.callbacks import resources
 from neutron_lib import constants as p_const
 from neutron_lib import context as neutron_context
 from neutron_lib import exceptions as n_exc
 from neutron_lib.plugins.ml2 import api
+from neutron_lib.utils import runtime
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
 import requests
 
-from neutron.common import utils
-from neutron.extensions import allowedaddresspairs as addr_pair
-from neutron.extensions import multiprovidernet as mpnet
 from neutron.extensions import securitygroup as sg
 from neutron.plugins.ml2 import driver_context
 
@@ -134,7 +135,7 @@ class SubnetFilter(ResourceFilterBase):
     def filter_update_attributes(cls, subnet, context):
         """Filter out subnet attributes for an update operation."""
         odl_utils.try_del(subnet, ['id', 'network_id', 'ip_version', 'cidr',
-                          'allocation_pools', 'tenant_id'])
+                          'tenant_id'])
         cls._filter_unmapped_null(subnet, cls._UNMAPPED_KEYS)
 
     @classmethod
@@ -170,7 +171,7 @@ class PortFilter(ResourceFilterBase):
     def filter_create_attributes(cls, port, context):
         """Filter out port attributes not required for a create."""
         cls._add_security_groups(port, context)
-        cls._fixup_allowed_ipaddress_pairs(port[addr_pair.ADDRESS_PAIRS])
+        cls._fixup_allowed_ipaddress_pairs(port[addr_apidef.ADDRESS_PAIRS])
         cls._filter_unmapped_null(port, cls._UNMAPPED_KEYS)
         odl_utils.try_del(port, ['status'])
 
@@ -192,7 +193,7 @@ class PortFilter(ResourceFilterBase):
     def filter_update_attributes(cls, port, context):
         """Filter out port attributes for an update operation."""
         cls._add_security_groups(port, context)
-        cls._fixup_allowed_ipaddress_pairs(port[addr_pair.ADDRESS_PAIRS])
+        cls._fixup_allowed_ipaddress_pairs(port[addr_apidef.ADDRESS_PAIRS])
         cls._filter_unmapped_null(port, cls._UNMAPPED_KEYS)
         odl_utils.try_del(port, ['network_id', 'id', 'status', 'tenant_id'])
 
@@ -237,6 +238,9 @@ class SecurityGroupRuleFilter(ResourceFilterBase):
         filters.filter_security_group_rule(sg_rule)
 
 
+@removals.removed_class(
+    'OpenDaylightDriver', version='Queens', removal_version='Rocky',
+    message="Usage of V1 drivers is deprecated. Please use V2 instead.")
 class OpenDaylightDriver(object):
 
     """OpenDaylight Python Driver for Neutron.
@@ -326,7 +330,7 @@ class OpenDaylightDriver(object):
         # TODO(yamahata): find dangling ODL resouce that was deleted in
         # neutron db
 
-    @utils.synchronized('odl-sync-full')
+    @runtime.synchronized('odl-sync-full')
     def sync_full(self, plugin):
         """Resync the entire database to ODL.
 
@@ -438,7 +442,7 @@ class OpenDaylightDriver(object):
             return (network[providernet.NETWORK_TYPE] in
                     VLAN_TRANSPARENT_NETWORK_TYPES)
         # multi providernet
-        segments = network.get(mpnet.SEGMENTS)
+        segments = network.get(mpnet_apidef.SEGMENTS)
         if segments is None:
             return True
         return all(segment[providernet.NETWORK_TYPE]
@@ -446,6 +450,9 @@ class OpenDaylightDriver(object):
                    for segment in segments)
 
 
+@removals.removed_class(
+    'OpenDaylightMechanismDriver', version='Queens', removal_version='Rocky',
+    message="Usage of V1 drivers is deprecated. Please use V2 instead.")
 class OpenDaylightMechanismDriver(api.MechanismDriver):
 
     """Mechanism Driver for OpenDaylight.
