@@ -16,7 +16,6 @@
 import logging
 from string import Template
 
-from neutron.db import provisioning_blocks
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
@@ -32,6 +31,8 @@ from oslo_serialization import jsonutils
 from requests import codes
 from requests import exceptions
 
+from neutron.db import provisioning_blocks
+
 from networking_odl.common import client as odl_client
 from networking_odl.common import odl_features
 from networking_odl.common import utils
@@ -332,7 +333,7 @@ class PseudoAgentDBBindingController(port_binding.PortBindingController):
         self._worker = PseudoAgentDBBindingWorker()
 
     @registry.receives(resources.PROCESS, [events.BEFORE_SPAWN])
-    def _before_spawn(self, resource, event, trigger, **kwargs):
+    def _before_spawn(self, resource, event, trigger, payload=None):
         self._prepopulate = PseudoAgentDBBindingPrePopulate(self._worker)
 
     def get_workers(self):
@@ -374,6 +375,16 @@ class PseudoAgentDBBindingController(port_binding.PortBindingController):
             return
 
         for raw_hconfig in agentdb:
+            # TODO(yamahata): don't poll hostconfig and update aliveness
+            # on hostconfig change of ODL. it's also necessary for
+            # scalability regarding to the number of compute nodes.
+            if not raw_hconfig['alive']:
+                LOG.warning(
+                    "Refusing to bind port %(pid)s to dead pseudo agent: "
+                    "%(agent)s",
+                    {'pid': port_context.current['id'], 'agent': raw_hconfig})
+                continue
+
             # do any $identifier substitution
             hconfig = self._substitute_hconfig_tmpl(port_context, raw_hconfig)
 
@@ -415,10 +426,6 @@ class PseudoAgentDBBindingController(port_binding.PortBindingController):
         # in this case ODL hostconfigs has the vif_type to bind for vnic_type
         vnic_type = port_context.current.get(portbindings.VNIC_TYPE)
 
-        if vnic_type != portbindings.VNIC_NORMAL:
-            LOG.error("Binding failed: unsupported VNIC %s", vnic_type)
-            return False
-
         vif_details = None
         for conf in confs:
             if conf["vnic_type"] == vnic_type:
@@ -427,9 +434,10 @@ class PseudoAgentDBBindingController(port_binding.PortBindingController):
                 vif_details = conf.get('vif_details', {})
                 break
         else:
-            vif_type = portbindings.VIF_TYPE_OVS  # default: OVS
-            LOG.warning("No supported vif type found for host %s!, "
-                        "defaulting to OVS", port_context.host)
+            LOG.error(
+                "Binding failed: unsupported VNIC %(vnic_type)s on %(host)s",
+                {'vnic_type': vnic_type, 'host': port_context.host})
+            return False
 
         if not vif_details:  # empty vif_details could be trouble, warn.
             LOG.warning("hostconfig:vif_details was empty!")
