@@ -12,8 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron.common import constants as n_consts
 from neutron_lib.api.definitions import portbindings
+from neutron_lib import constants
+from neutron_lib.db import constants as db_const
 from neutron_lib.plugins import constants as nlib_const
 from neutron_lib.services.qos import base
 from neutron_lib.services.qos import constants as qos_consts
@@ -32,11 +33,11 @@ LOG = logging.getLogger(__name__)
 SUPPORTED_RULES = {
     qos_consts.RULE_TYPE_BANDWIDTH_LIMIT: {
         qos_consts.MAX_KBPS: {
-            'type:range': [0, n_consts.DB_INTEGER_MAX_VALUE]},
+            'type:range': [0, db_const.DB_INTEGER_MAX_VALUE]},
         qos_consts.MAX_BURST: {
-            'type:range': [0, n_consts.DB_INTEGER_MAX_VALUE]},
+            'type:range': [0, db_const.DB_INTEGER_MAX_VALUE]},
         qos_consts.DIRECTION: {
-            'type:values': [n_consts.EGRESS_DIRECTION]}
+            'type:values': [constants.EGRESS_DIRECTION]}
     },
 }
 VIF_TYPES = [portbindings.VIF_TYPE_OVS, portbindings.VIF_TYPE_VHOST_USER]
