@@ -15,32 +15,44 @@
 #
 
 import functools
+import os
 
 from neutron.common import utils
-from neutron.plugins.ml2 import config
+from neutron.tests import base
+from neutron.tests.common import helpers
 from neutron.tests.unit.plugins.ml2 import test_plugin
+from oslo_config import cfg
+from oslo_config import fixture as config_fixture
 
 from networking_odl.common import client
 from networking_odl.common import constants as odl_const
 from networking_odl.common import utils as odl_utils
 from networking_odl.db import db
+from networking_odl.tests import base as test_base
 from networking_odl.tests.unit import test_base_db
 
 
 class OdlTestsBase(object):
+    #  this is stolen from neutron.tests.functional.base
+    # This is the directory from which infra fetches log files
+    # for functional tests.
+    DEFAULT_LOG_DIR = os.path.join(helpers.get_test_log_path(),
+                                   'dsvm-functional-logs')
+
     def setUp(self):
-        config.cfg.CONF.set_override(
-            'url', 'http://127.0.0.1:8181/controller/nb/v2/neutron', 'ml2_odl')
-        config.cfg.CONF.set_override('username', 'admin', 'ml2_odl')
-        config.cfg.CONF.set_override('password', 'admin', 'ml2_odl')
-        config.cfg.CONF.set_override('mechanism_drivers',
-                                     self._mechanism_drivers,
-                                     group='ml2')
-        config.cfg.CONF.set_override('extension_drivers',
-                                     ['qos', 'port_security'],
-                                     group='ml2')
+        self.cfg = self.useFixture(config_fixture.Config())
+        self.cfg.config(
+            url='http://127.0.0.1:8181/controller/nb/v2/neutron',
+            group='ml2_odl')
+        self.cfg.config(username='admin', group='ml2_odl')
+        self.cfg.config(password='admin', group='ml2_odl')
+        self.cfg.config(mechanism_drivers=self._mechanism_drivers, group='ml2')
+        self.cfg.config(extension_drivers=[
+                        'qos', 'port_security'], group='ml2')
         self.client = client.OpenDaylightRestClient.create_client()
         super(OdlTestsBase, self).setUp()
+        base.setup_test_logging(
+            cfg.CONF, self.DEFAULT_LOG_DIR, "%s.txt" % self.id())
 
     def setup_parent(self):
         """Perform parent setup with the common plugin configuration class."""
@@ -92,6 +104,7 @@ class OdlTestsBase(object):
 class V2DriverAdjustment(test_base_db.ODLBaseDbTestCase):
     def setUp(self):
         super(V2DriverAdjustment, self).setUp()
+        self.useFixture(test_base.JournalWorkerPidFileFixture())
 
     def get_odl_resource(self, resource_type, resource):
         def no_journal_rows():
