@@ -68,7 +68,7 @@ VERSION_TABLE = 'odl_alembic_version'
 
 class _TestModelsMigrationsODL(test_migrations._TestModelsMigrations):
     def db_sync(self, engine):
-        cfg.CONF.set_override('connection', engine.url, group='database')
+        self.cfg.config(connection=engine.url, group='database')
         for conf in migration.get_alembic_configs():
             self.alembic_config = conf
             self.alembic_config.neutron_config = cfg.CONF
@@ -127,13 +127,7 @@ class _TestModelsMigrationsODL(test_migrations._TestModelsMigrations):
                 not rendered_meta_def.reflected and
                 meta_def.for_update == rendered_meta_def.for_update):
             return False
-        if (diff_elem[0][0] == 'modify_default' and
-                diff_elem[0][2] == 'opendaylightjournal' and
-                meta_def is None and
-                isinstance(rendered_meta_def, schema.DefaultClause) and
-                isinstance(rendered_meta_def.arg, sql.functions.now) and
-                not rendered_meta_def.reflected):
-            return False
+
         return True
 
     def filter_metadata_diff(self, diff):
