@@ -16,7 +16,6 @@
 import mock
 
 from neutron.tests.unit.plugins.ml2 import test_plugin
-from oslo_config import cfg
 
 from networking_odl.common import client
 from networking_odl.journal import journal
@@ -28,13 +27,11 @@ from networking_odl.tests.unit import test_base_db
 class OpenDaylightConfigBase(test_plugin.Ml2PluginV2TestCase,
                              test_base_db.ODLBaseDbTestCase):
     def setUp(self):
-        self.useFixture(base.OpenDaylightJournalThreadFixture())
+        self.journal_thread_fixture = self.useFixture(
+            base.OpenDaylightJournalThreadFixture())
         self.useFixture(base.OpenDaylightRestClientFixture())
+        self.useFixture(base.OpenDaylightFullSyncFixture())
         super(OpenDaylightConfigBase, self).setUp()
-        cfg.CONF.set_override('mechanism_drivers',
-                              ['logger', 'opendaylight_v2'], 'ml2')
-        cfg.CONF.set_override('extension_drivers',
-                              ['port_security', 'qos'], 'ml2')
         self.thread = journal.OpenDaylightJournalThread()
 
     def run_journal_processing(self):
