@@ -16,14 +16,15 @@
 import mock
 import requests
 
-from neutron.extensions import external_net as external_net
 from neutron.plugins.ml2 import plugin
 from neutron.tests import base
 from neutron.tests.unit.db import test_db_base_plugin_v2
 from neutron.tests.unit import testlib_api
+from neutron_lib.api.definitions import external_net
 from neutron_lib.plugins import constants
 from neutron_lib.plugins import directory
 from oslo_config import cfg
+from oslo_config import fixture as config_fixture
 from oslo_serialization import jsonutils
 from oslo_utils import uuidutils
 
@@ -48,23 +49,25 @@ class OpenDayLightMechanismConfigTests(testlib_api.SqlTestCase):
     def setUp(self):
         self.useFixture(odl_base.OpenDaylightRestClientFixture())
         self.useFixture(odl_base.OpenDaylightFeaturesFixture())
+        self.cfg = self.useFixture(config_fixture.Config())
+        self.useFixture(odl_base.OpenDaylightJournalThreadFixture())
         super(OpenDayLightMechanismConfigTests, self).setUp()
-        cfg.CONF.set_override('mechanism_drivers',
-                              ['logger', 'opendaylight_v2'], 'ml2')
-        cfg.CONF.set_override('port_binding_controller',
-                              'legacy-port-binding', 'ml2_odl')
+        self.cfg.config(mechanism_drivers=[
+                        'logger', 'opendaylight_v2'], group='ml2')
+        self.cfg.config(
+            port_binding_controller='legacy-port-binding', group='ml2_odl')
 
     def _set_config(self, url='http://127.0.0.1:9999', username='someuser',
                     password='somepass'):
-        cfg.CONF.set_override('url', url, 'ml2_odl')
-        cfg.CONF.set_override('username', username, 'ml2_odl')
-        cfg.CONF.set_override('password', password, 'ml2_odl')
+        self.cfg.config(url=url, group='ml2_odl')
+        self.cfg.config(username=username, group='ml2_odl')
+        self.cfg.config(password=password, group='ml2_odl')
 
     def _test_missing_config(self, **kwargs):
         self._set_config(**kwargs)
         self.assertRaisesRegex(cfg.RequiredOptError,
-                               'value required for option \w+ in group '
-                               '\[ml2_odl\]',
+                               r'value required for option \w+ in group '
+                               r'\[ml2_odl\]',
                                plugin.Ml2Plugin)
 
     def test_valid_config(self):
@@ -100,12 +103,12 @@ class OpenDaylightL3TestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                              test_base_db.ODLBaseDbTestCase,
                              base.BaseTestCase):
     def setUp(self):
-        cfg.CONF.set_override("core_plugin",
-                              'neutron.plugins.ml2.plugin.Ml2Plugin')
-        cfg.CONF.set_override('mechanism_drivers',
-                              ['logger', 'opendaylight_v2'], 'ml2')
+        self.cfg = self.useFixture(config_fixture.Config())
+        self.cfg.config(core_plugin='neutron.plugins.ml2.plugin.Ml2Plugin')
+        self.cfg.config(mechanism_drivers=[
+                        'logger', 'opendaylight_v2'], group='ml2')
         self.useFixture(odl_base.OpenDaylightRestClientFixture())
-        cfg.CONF.set_override("service_plugins", ['odl-router_v2'])
+        self.cfg.config(service_plugins=['odl-router_v2'])
         core_plugin = cfg.CONF.core_plugin
         service_plugins = {'l3_plugin_name': 'odl-router_v2'}
         self.useFixture(odl_base.OpenDaylightJournalThreadFixture())
@@ -117,6 +120,7 @@ class OpenDaylightL3TestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                           'sync_from_callback_postcommit').start()
         self.useFixture(odl_base.OpenDaylightPeriodicTaskFixture())
         self.useFixture(odl_base.OpenDaylightFeaturesFixture())
+        self.useFixture(odl_base.OpenDaylightPseudoAgentPrePopulateFixture())
         super(OpenDaylightL3TestCase, self).setUp(
             plugin=core_plugin, service_plugins=service_plugins)
         self.plugin = directory.get_plugin()
@@ -141,7 +145,9 @@ class OpenDaylightL3TestCase(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
     def _get_mock_floatingip_operation_info(network, subnet):
         floatingip = {odl_const.ODL_FLOATINGIP:
                       {'floating_network_id': network['network']['id'],
-                       'tenant_id': network['network']['tenant_id']}}
+                       'tenant_id': network['network']['tenant_id'],
+                       'subnet_id': None,
+                       'floating_ip_address': None}}
         return floatingip
 
     @staticmethod
