@@ -20,24 +20,22 @@ import mock
 import testscenarios
 
 from oslo_config import cfg
+from oslo_config import fixture as config_fixture
 from oslo_serialization import jsonutils
 import requests
-import webob.exc
 
 from neutron.db import segments_db
-from neutron.extensions import multiprovidernet as mpnet
-from neutron.plugins.ml2 import config
-from neutron.plugins.ml2 import driver_api as api
 from neutron.plugins.ml2 import driver_context as driver_context
 from neutron.plugins.ml2 import models
 from neutron.plugins.ml2 import plugin
 from neutron.tests import base
 from neutron.tests.unit.plugins.ml2 import test_plugin
 from neutron.tests.unit import testlib_api
+from neutron_lib.api.definitions import multiprovidernet as mpnet_apidef
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import provider_net as providernet
 from neutron_lib import constants as n_constants
-from neutron_lib.plugins.ml2 import api as ml2_api
+from neutron_lib.plugins.ml2 import api
 
 from networking_odl.common import client
 from networking_odl.common import constants as odl_const
@@ -141,24 +139,24 @@ class OpenDayLightMechanismConfigTests(testlib_api.SqlTestCase):
     def setUp(self):
         self.useFixture(odl_base.OpenDaylightFeaturesFixture())
         self.useFixture(odl_base.OpenDaylightPseudoAgentPrePopulateFixture())
+        self.cfg = self.useFixture(config_fixture.Config())
         super(OpenDayLightMechanismConfigTests, self).setUp()
-        config.cfg.CONF.set_override('mechanism_drivers',
-                                     ['logger', 'opendaylight'],
-                                     'ml2')
-        config.cfg.CONF.set_override('port_binding_controller',
-                                     'legacy-port-binding', 'ml2_odl')
+        self.cfg.config(mechanism_drivers=[
+                        'logger', 'opendaylight'], group='ml2')
+        self.cfg.config(
+            port_binding_controller='legacy-port-binding', group='ml2_odl')
 
     def _set_config(self, url='http://127.0.0.1:9999', username='someuser',
                     password='somepass'):
-        config.cfg.CONF.set_override('url', url, 'ml2_odl')
-        config.cfg.CONF.set_override('username', username, 'ml2_odl')
-        config.cfg.CONF.set_override('password', password, 'ml2_odl')
+        self.cfg.config(url=url, group='ml2_odl')
+        self.cfg.config(username=username, group='ml2_odl')
+        self.cfg.config(password=password, group='ml2_odl')
 
     def _test_missing_config(self, **kwargs):
         self._set_config(**kwargs)
-        self.assertRaisesRegex(config.cfg.RequiredOptError,
-                               'value required for option \w+ in group '
-                               '\[ml2_odl\]',
+        self.assertRaisesRegex(cfg.RequiredOptError,
+                               r'value required for option \w+ in group '
+                               r'\[ml2_odl\]',
                                plugin.Ml2Plugin)
 
     def test_valid_config(self):
@@ -175,39 +173,6 @@ class OpenDayLightMechanismConfigTests(testlib_api.SqlTestCase):
         self._test_missing_config(password=None)
 
 
-class OpenDaylightMechanismTestBasicGet(test_plugin.TestMl2BasicGet,
-                                        OpenDaylightTestCase):
-    pass
-
-
-class OpenDaylightMechanismTestNetworksV2(test_plugin.TestMl2NetworksV2,
-                                          OpenDaylightTestCase):
-    pass
-
-
-class OpenDaylightMechanismTestSubnetsV2(test_plugin.TestMl2SubnetsV2,
-                                         OpenDaylightTestCase):
-    pass
-
-
-class OpenDaylightMechanismTestPortsV2(test_plugin.TestMl2PortsV2,
-                                       OpenDaylightTestCase):
-
-    def setUp(self):
-        mock.patch.object(
-            mech_driver.OpenDaylightDriver,
-            'out_of_sync',
-            new_callable=mock.PropertyMock(return_value=False)).start()
-        super(OpenDaylightMechanismTestPortsV2, self).setUp()
-
-    def test_update_port_mac(self):
-        self.check_update_port_mac(
-            host_arg={portbindings.HOST_ID: HOST},
-            arg_list=(portbindings.HOST_ID,),
-            expected_status=webob.exc.HTTPConflict.code,
-            expected_error='PortBound')
-
-
 class DataMatcher(object):
 
     def __init__(self, operation, object_type, context):
@@ -308,9 +273,10 @@ class OpenDaylightMechanismDriverTestCase(base.BaseTestCase):
         self.useFixture(odl_base.OpenDaylightRestClientFixture())
         self.useFixture(odl_base.OpenDaylightFeaturesFixture())
         self.useFixture(odl_base.OpenDaylightPseudoAgentPrePopulateFixture())
+        self.cfg = self.useFixture(config_fixture.Config())
         super(OpenDaylightMechanismDriverTestCase, self).setUp()
-        config.cfg.CONF.set_override('mechanism_drivers',
-                                     ['logger', 'opendaylight'], 'ml2')
+        self.cfg.config(mechanism_drivers=[
+                        'logger', 'opendaylight'], group='ml2')
         self.mech = mech_driver.OpenDaylightMechanismDriver()
         self.mech.initialize()
 
@@ -368,13 +334,17 @@ class OpenDaylightMechanismDriverTestCase(base.BaseTestCase):
                 method(context)
         mock_method.assert_called_once_with(
             headers={'Content-Type': 'application/json'},
-            timeout=config.cfg.CONF.ml2_odl.timeout, *args, **kwargs)
+            timeout=cfg.CONF.ml2_odl.timeout, *args, **kwargs)
+        if args[0] == 'put' and \
+                kwargs['data']._object_type == odl_const.ODL_SUBNET:
+            alloc_pools = kwargs['data']._data['allocation_pools']
+            self.assertEqual(FAKE_SUBNET['allocation_pools'], alloc_pools)
 
     def _test_create_resource_postcommit(self, object_type, status_code,
                                          exc_class=None):
         method = getattr(self.mech, 'create_%s_postcommit' % object_type)
         context = self._get_mock_operation_context(object_type)
-        url = '%s/%ss' % (config.cfg.CONF.ml2_odl.url, object_type)
+        url = '%s/%ss' % (cfg.CONF.ml2_odl.url, object_type)
         kwargs = {'url': url,
                   'data': DataMatcher(odl_const.ODL_CREATE, object_type,
                                       context)}
@@ -385,7 +355,7 @@ class OpenDaylightMechanismDriverTestCase(base.BaseTestCase):
                                          exc_class=None):
         method = getattr(self.mech, 'update_%s_postcommit' % object_type)
         context = self._get_mock_operation_context(object_type)
-        url = '%s/%ss/%s' % (config.cfg.CONF.ml2_odl.url, object_type,
+        url = '%s/%ss/%s' % (cfg.CONF.ml2_odl.url, object_type,
                              context.current['id'])
         kwargs = {'url': url,
                   'data': DataMatcher(odl_const.ODL_UPDATE, object_type,
@@ -397,7 +367,7 @@ class OpenDaylightMechanismDriverTestCase(base.BaseTestCase):
                                          exc_class=None):
         method = getattr(self.mech, 'delete_%s_postcommit' % object_type)
         context = self._get_mock_operation_context(object_type)
-        url = '%s/%ss/%s' % (config.cfg.CONF.ml2_odl.url, object_type,
+        url = '%s/%ss/%s' % (cfg.CONF.ml2_odl.url, object_type,
                              context.current['id'])
         kwargs = {'url': url, 'data': None}
         self._test_single_operation(method, context, status_code, exc_class,
@@ -556,22 +526,23 @@ class TestOpenDaylightMechanismDriver(base.DietTestCase):
         self.useFixture(odl_base.OpenDaylightRestClientFixture())
         self.useFixture(odl_base.OpenDaylightFeaturesFixture())
         self.useFixture(odl_base.OpenDaylightPseudoAgentPrePopulateFixture())
+        self.cfg = self.useFixture(config_fixture.Config())
         super(TestOpenDaylightMechanismDriver, self).setUp()
-        config.cfg.CONF.set_override('mechanism_drivers',
-                                     ['logger', 'opendaylight'], 'ml2')
+        self.cfg.config(mechanism_drivers=[
+                        'logger', 'opendaylight'], group='ml2')
 
     # given valid  and invalid segments
     valid_segment = {
-        ml2_api.ID: 'API_ID',
-        ml2_api.NETWORK_TYPE: n_constants.TYPE_LOCAL,
-        ml2_api.SEGMENTATION_ID: 'API_SEGMENTATION_ID',
-        ml2_api.PHYSICAL_NETWORK: 'API_PHYSICAL_NETWORK'}
+        api.ID: 'API_ID',
+        api.NETWORK_TYPE: n_constants.TYPE_LOCAL,
+        api.SEGMENTATION_ID: 'API_SEGMENTATION_ID',
+        api.PHYSICAL_NETWORK: 'API_PHYSICAL_NETWORK'}
 
     invalid_segment = {
-        ml2_api.ID: 'API_ID',
-        ml2_api.NETWORK_TYPE: n_constants.TYPE_NONE,
-        ml2_api.SEGMENTATION_ID: 'API_SEGMENTATION_ID',
-        ml2_api.PHYSICAL_NETWORK: 'API_PHYSICAL_NETWORK'}
+        api.ID: 'API_ID',
+        api.NETWORK_TYPE: n_constants.TYPE_NONE,
+        api.SEGMENTATION_ID: 'API_SEGMENTATION_ID',
+        api.PHYSICAL_NETWORK: 'API_PHYSICAL_NETWORK'}
 
     def test_bind_port_front_end(self):
         given_front_end = mech_driver.OpenDaylightMechanismDriver()
@@ -587,7 +558,7 @@ class TestOpenDaylightMechanismDriver(base.DietTestCase):
         # then context binding is setup with returned vif_type and valid
         # segment API ID
         given_port_context.set_binding.assert_called_once_with(
-            self.valid_segment[ml2_api.ID], portbindings.VIF_TYPE_OVS,
+            self.valid_segment[api.ID], portbindings.VIF_TYPE_OVS,
             given_back_end.port_binding_controller.vif_details,
             status=n_constants.PORT_STATUS_ACTIVE)
 
@@ -658,6 +629,6 @@ class TestOpenDaylightDriverVlanTransparency(
     def test_network_segments(self):
         segments = [{providernet.NETWORK_TYPE: type_}
                     for type_ in self.network_types]
-        context = self._driver_context({mpnet.SEGMENTS: segments})
+        context = self._driver_context({mpnet_apidef.SEGMENTS: segments})
         self.assertEqual(self.expected,
                          self.mech.check_vlan_transparency(context))
