@@ -22,14 +22,14 @@ import testscenarios
 
 from neutron.db.models import securitygroup
 from neutron.db import segments_db
-from neutron.extensions import multiprovidernet as mpnet
 from neutron.plugins.ml2 import plugin
-from neutron.tests.unit.plugins.ml2 import test_plugin
 from neutron.tests.unit import testlib_api
+from neutron_lib.api.definitions import multiprovidernet as mpnet_apidef
 from neutron_lib.api.definitions import provider_net as providernet
 from neutron_lib import constants as n_constants
 from neutron_lib.plugins import directory
 from oslo_config import cfg
+from oslo_config import fixture as config_fixture
 from oslo_serialization import jsonutils
 from oslo_utils import uuidutils
 
@@ -57,25 +57,27 @@ SG_RULE_FAKE_ID = uuidutils.generate_uuid()
 
 class OpenDayLightMechanismConfigTests(testlib_api.SqlTestCase):
     def setUp(self):
-        super(OpenDayLightMechanismConfigTests, self).setUp()
         self.useFixture(base.OpenDaylightFeaturesFixture())
         self.useFixture(base.OpenDaylightJournalThreadFixture())
-        cfg.CONF.set_override('mechanism_drivers',
-                              ['logger', 'opendaylight_v2'], 'ml2')
-        cfg.CONF.set_override('port_binding_controller',
-                              'legacy-port-binding', 'ml2_odl')
+        self.useFixture(base.OpenDaylightPseudoAgentPrePopulateFixture())
+        self.cfg = self.useFixture(config_fixture.Config())
+        super(OpenDayLightMechanismConfigTests, self).setUp()
+        self.cfg.config(mechanism_drivers=[
+                        'logger', 'opendaylight_v2'], group='ml2')
+        self.cfg.config(
+            port_binding_controller='legacy-port-binding', group='ml2_odl')
 
     def _set_config(self, url='http://127.0.0.1:9999', username='someuser',
                     password='somepass'):
-        cfg.CONF.set_override('url', url, 'ml2_odl')
-        cfg.CONF.set_override('username', username, 'ml2_odl')
-        cfg.CONF.set_override('password', password, 'ml2_odl')
+        self.cfg.config(url=url, group='ml2_odl')
+        self.cfg.config(username=username, group='ml2_odl')
+        self.cfg.config(password=password, group='ml2_odl')
 
     def _test_missing_config(self, **kwargs):
         self._set_config(**kwargs)
         self.assertRaisesRegex(cfg.RequiredOptError,
-                               'value required for option \w+ in group '
-                               '\[ml2_odl\]',
+                               r'value required for option \w+ in group '
+                               r'\[ml2_odl\]',
                                plugin.Ml2Plugin)
 
     def test_valid_config(self):
@@ -92,24 +94,41 @@ class OpenDayLightMechanismConfigTests(testlib_api.SqlTestCase):
         self._test_missing_config(password=None)
 
 
-class OpenDaylightMechanismTestBasicGet(test_plugin.TestMl2BasicGet,
-                                        base_v2.OpenDaylightTestCase):
-    pass
+class _OpenDaylightMechanismBase(base_v2.OpenDaylightTestCase):
+    _mechanism_drivers = ['logger', 'opendaylight_v2']
+    # TODO(mpeterson): Add a test to make sure extension_drivers are honored.
+    _extension_drivers = ['port_security', 'qos']
 
+    def setUp(self):
+        mech_initialize_patcher = mock.patch.object(
+            mech_driver_v2.OpenDaylightMechanismDriver,
+            'initialize',
+            autospec=True,
+            side_effect=mech_driver_v2.OpenDaylightMechanismDriver.initialize
+        )
+        self.mech_initialize_mock = mech_initialize_patcher.start()
+        mock.patch('networking_odl.common.odl_features.init').start()
+        # NOTE(mpeterson): We cannot use stop in the following cleanup because
+        # several of the following fixtures and setUp() add a cleanup for
+        # stopall. The reason to add the stopall ourselves is to make sure
+        # that it will be stopped if anything were to change in the future.
+        self.addCleanup(mock.patch.stopall)
+        self.useFixture(base.OpenDaylightPseudoAgentPrePopulateFixture())
+        self.cfg = self.useFixture(config_fixture.Config())
+        self.cfg.config(extension_drivers=self._extension_drivers, group='ml2')
+        super(_OpenDaylightMechanismBase, self).setUp()
 
-class OpenDaylightMechanismTestNetworksV2(test_plugin.TestMl2NetworksV2,
-                                          base_v2.OpenDaylightTestCase):
-    pass
+    def test_mechanism_driver_is_initialized(self):
+        """Test that the mech driver is initialized.
 
-
-class OpenDaylightMechanismTestSubnetsV2(test_plugin.TestMl2SubnetsV2,
-                                         base_v2.OpenDaylightTestCase):
-    pass
-
-
-class OpenDaylightMechanismTestPortsV2(test_plugin.TestMl2PortsV2,
-                                       base_v2.OpenDaylightTestCase):
-    pass
+        This test will allow us know if the mech driver is not initialized
+        in case there is a change in the way Ml2PluginV2TestCase instantiate
+        them
+        """
+        # NOTE(mpeterson): Because of the autospec the mock lacks
+        # the helper assert_called_once
+        msg = "The opendaylight_v2 ML2 Mechanism Driver was not initialized"
+        self.assertTrue(self.mech_initialize_mock.called, msg)
 
 
 class DataMatcher(object):
@@ -152,6 +171,7 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
     def setUp(self):
         self.useFixture(base.OpenDaylightFeaturesFixture())
         self.useFixture(base.OpenDaylightJournalThreadFixture())
+        self.useFixture(base.OpenDaylightPseudoAgentPrePopulateFixture())
         super(OpenDaylightMechanismDriverTestCase, self).setUp()
         self.mech = mech_driver_v2.OpenDaylightMechanismDriver()
         self.mech.initialize()
@@ -314,6 +334,12 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
                             security_group={'security_group_rules':
                                             {'id': SG_RULE_FAKE_ID}},
                             security_group_rule_ids=[SG_RULE_FAKE_ID])
+            elif (object_type == odl_const.ODL_SG_RULE and
+                  operation == odl_const.ODL_DELETE):
+                with self.db_session.begin(subtransactions=True):
+                    self.mech.sync_from_callback_precommit(
+                        plugin_context, operation, res_type, res_id,
+                        context_, security_group_id=SG_FAKE_ID)
             else:
                 with self.db_session.begin(subtransactions=True):
                     self.mech.sync_from_callback_precommit(
@@ -461,7 +487,7 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
 
         # Test if the cleanup marks this in the desired state
         # based on the last_retried timestamp
-        cleanup.JournalCleanup().cleanup_processing_rows(self.db_context)
+        cleanup.cleanup_processing_rows(self.db_context)
 
         # Verify that the Db row is in the desired state
         rows = db.get_all_db_rows_by_state(self.db_session, expected_state)
@@ -616,6 +642,32 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
                             'tenant_id': 'test-tenant',
                             'id': SG_FAKE_ID, 'name': 'test_sg'})])
 
+    def test_sg_rule_delete(self):
+        with mock.patch.object(journal, 'record') as record:
+            context = self._get_mock_operation_context(odl_const.ODL_SG_RULE)
+            res_id = context[odl_const.ODL_SG_RULE]['id']
+            rule = mock.Mock()
+            rule.id = SG_RULE_FAKE_ID
+            rule.security_group_id = SG_FAKE_ID
+            kwargs = {'security_group_rule_id': SG_RULE_FAKE_ID,
+                      'security_group_id': SG_FAKE_ID}
+            with self.db_session.begin(subtransactions=True):
+                self.mech.sync_from_callback_precommit(
+                    self.db_context, odl_const.ODL_DELETE,
+                    callback._RESOURCE_MAPPING[odl_const.ODL_SG_RULE],
+                    res_id, context, **kwargs)
+            record.assert_has_calls(
+                [mock.call(mock.ANY, 'security_group_rule',
+                           SG_RULE_FAKE_ID, 'delete', [SG_FAKE_ID])])
+
+    def test_subnet_allocation_pools(self):
+        context = self._get_mock_operation_context(odl_const.ODL_SUBNET)
+        alloc_pool = context.current['allocation_pools']
+        self._call_operation_object(odl_const.ODL_UPDATE,
+                                    odl_const.ODL_SUBNET)
+        row = db.get_oldest_pending_db_row_with_lock(self.db_session)
+        self.assertEqual(alloc_pool, row.data['allocation_pools'])
+
     def test_sync_multiple_updates(self):
         # add 2 updates
         for i in range(2):
@@ -664,7 +716,7 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
                     self.assertEqual(port[key], value)
 
 
-class _OpenDaylightDriverVlanTransparencyBase(base_v2.OpenDaylightTestCase):
+class _OpenDaylightDriverVlanTransparencyBase(_OpenDaylightMechanismBase):
     def _driver_context(self, network):
         return mock.MagicMock(current=network)
 
@@ -713,6 +765,6 @@ class TestOpenDaylightDriverVlanTransparency(
     def test_network_segments(self):
         segments = [{providernet.NETWORK_TYPE: type_}
                     for type_ in self.network_types]
-        context = self._driver_context({mpnet.SEGMENTS: segments})
+        context = self._driver_context({mpnet_apidef.SEGMENTS: segments})
         self.assertEqual(self.expected,
                          self.mech.check_vlan_transparency(context))
