@@ -19,21 +19,24 @@ from string import Template
 
 import fixtures
 import mock
-from oslo_config import cfg
 from oslo_serialization import jsonutils
 from requests.exceptions import HTTPError
 
 from neutron.db import provisioning_blocks
-from neutron.plugins.ml2 import driver_api as api
 from neutron.plugins.ml2 import driver_context as ctx
 from neutron.plugins.ml2 import plugin as ml2_plugin
 from neutron.tests.unit.db import test_db_base_plugin_v2 as test_plugin
 from neutron.tests.unit import testlib_api
 from neutron_lib.api.definitions import portbindings
+from neutron_lib.callbacks import events
+from neutron_lib.callbacks import registry
+from neutron_lib.callbacks import resources
 from neutron_lib import constants as n_const
+from neutron_lib import fixture
 from neutron_lib.plugins import constants as plugin_constants
 from neutron_lib.plugins import directory
-from neutron_lib.plugins.ml2 import api as ml2_api
+from neutron_lib.plugins.ml2 import api
+from oslo_config import fixture as config_fixture
 
 from networking_odl.common import odl_features
 from networking_odl.common import websocket_client
@@ -44,6 +47,17 @@ from networking_odl.tests import base
 
 AGENTDB_BINARY = 'neutron-odlagent-portbinding'
 L2_TYPE = "ODL L2"
+# test data hostconfig and hostconfig-dbget
+SAMPLE_ODL_HCONFIGS = {"hostconfigs": {"hostconfig": [
+    {"host-id": "devstack",
+     "host-type": "ODL L2",
+     "config": """{"supported_vnic_types": [
+                {"vnic_type": "normal", "vif_type": "ovs",
+                 "vif_details": {}}],
+                "allowed_network_types": [
+                "local", "vlan", "vxlan", "gre"],
+                "bridge_mappings": {"physnet1": "br-ex"}}"""}
+]}}
 
 
 class OpenDaylightAgentDBFixture(fixtures.Fixture):
@@ -51,6 +65,7 @@ class OpenDaylightAgentDBFixture(fixtures.Fixture):
         super(OpenDaylightAgentDBFixture, self)._setUp()
         fake_agents_db = mock.MagicMock()
         fake_agents_db.create_or_update_agent = mock.MagicMock()
+        self.useFixture(fixture.PluginDirectoryFixture())
         directory.add_plugin(plugin_constants.CORE, fake_agents_db)
 
 
@@ -60,6 +75,7 @@ class TestPseudoAgentDBBindingTaskBase(base.DietTestCase):
     def setUp(self):
         """Setup test."""
         self.useFixture(base.OpenDaylightRestClientFixture())
+        self.useFixture(base.OpenDaylightPseudoAgentPrePopulateFixture())
         self.useFixture(OpenDaylightAgentDBFixture())
         super(TestPseudoAgentDBBindingTaskBase, self).setUp()
 
@@ -91,24 +107,104 @@ class TestPseudoAgentDBBindingTaskBase(base.DietTestCase):
                 self.assertEqual(self.task._rest_get_hostconfigs(), [])
 
 
+class TestPseudoAgentDBBindingPrePopulate(base.DietTestCase):
+    KNOWN_HOST = 'known_host'
+    AGENT_TYPE = pseudo_agentdb_binding.PseudoAgentDBBindingWorker.L2_TYPE
+
+    def setUp(self):
+        self.useFixture(base.OpenDaylightRestClientFixture())
+        self.useFixture(OpenDaylightAgentDBFixture())
+        super(TestPseudoAgentDBBindingPrePopulate, self).setUp()
+        self.useFixture(fixture.CallbackRegistryFixture())
+
+        self.ml2_plugin = mock.Mock()
+        self.ml2_plugin.get_agents = mock.Mock(return_value=[])
+        self.worker = mock.Mock()
+        self.worker.known_agent = mock.Mock(return_value=False)
+        self.worker.add_known_agent = mock.Mock()
+        self.worker.update_agetns_db_row = mock.Mock()
+        self.prepopulate = (pseudo_agentdb_binding.
+                            PseudoAgentDBBindingPrePopulate(self.worker))
+
+    def _call_before_port_binding(self, host):
+        kwargs = {
+            'context': mock.Mock(),
+            'port': {
+                portbindings.HOST_ID: host
+            }
+        }
+        registry.notify(resources.PORT, events.BEFORE_CREATE, self.ml2_plugin,
+                        **kwargs)
+
+    def test_unspecified(self):
+        self._call_before_port_binding(n_const.ATTR_NOT_SPECIFIED)
+        self.worker.known_agent.assert_not_called()
+
+    def test_empty_host(self):
+        self._call_before_port_binding('')
+        self.worker.known_agent.assert_not_called()
+
+    def test_known_agent(self):
+        self.worker.known_agent = mock.Mock(return_value=True)
+        self._call_before_port_binding(self.KNOWN_HOST)
+        self.worker.known_agent.assert_called()
+        self.ml2_plugin.get_agents.assert_not_called()
+
+    def test_agentdb_alive(self):
+        self.ml2_plugin.get_agents = mock.Mock(return_value=[
+            {'host': self.KNOWN_HOST,
+             'agent_type': self.AGENT_TYPE,
+             'alive': True}])
+        self._call_before_port_binding(self.KNOWN_HOST)
+        self.worker.known_agent.assert_called()
+        self.ml2_plugin.get_agents.assert_called()
+        self.worker.add_known_agents.assert_called_with([
+            {'host': self.KNOWN_HOST,
+             'agent_type': self.AGENT_TYPE,
+             'alive': True}])
+        self.worker.update_agents_db_row.assert_not_called()
+
+    def test_agentdb_dead(self):
+        self.ml2_plugin.get_agents = mock.Mock(return_value=[
+            {'host': self.KNOWN_HOST,
+             'agent_type': self.AGENT_TYPE,
+             'alive': False}])
+        self._call_before_port_binding(self.KNOWN_HOST)
+        self.worker.known_agent.assert_called()
+        self.ml2_plugin.get_agents.assert_called()
+        self.worker.add_known_agents.assert_not_called()
+
+    def test_unkown_hostconfig(self):
+        with mock.patch.object(self.prepopulate,
+                               'odl_rest_client') as mock_rest_client:
+            mock_response = mock.Mock()
+            mock_response.json = mock.Mock(
+                return_value=SAMPLE_ODL_HCONFIGS['hostconfigs'])
+            mock_rest_client.get = mock.Mock(return_value=mock_response)
+            self._call_before_port_binding(self.KNOWN_HOST)
+            self.worker.known_agent.assert_called()
+            self.ml2_plugin.get_agents.assert_called()
+            self.worker.add_known_agent.assert_not_called()
+            self.worker.update_agents_db_row.assert_called_once()
+
+    def test_http_error(self):
+        with mock.patch.object(self.prepopulate,
+                               'odl_rest_client') as mock_rest_client:
+            mock_rest_client.get = mock.Mock(side_effect=Exception('error'))
+            self._call_before_port_binding(self.KNOWN_HOST)
+            self.worker.known_agent.assert_called()
+            self.ml2_plugin.get_agents.assert_called()
+            self.worker.add_known_agent.assert_not_called()
+            self.worker.update_agents_db_row.assert_not_called()
+
+
 class TestPseudoAgentDBBindingWorker(base.DietTestCase):
     """Test class for AgentDBPortBinding."""
 
-    # test data hostconfig and hostconfig-dbget
-    sample_odl_hconfigs = {"hostconfigs": {"hostconfig": [
-        {"host-id": "devstack",
-         "host-type": "ODL L2",
-         "config": """{"supported_vnic_types": [
-                    {"vnic_type": "normal", "vif_type": "ovs",
-                     "vif_details": {}}],
-                    "allowed_network_types": [
-                    "local", "vlan", "vxlan", "gre"],
-                    "bridge_mappings": {"physnet1": "br-ex"}}"""}
-    ]}}
-
     def setUp(self):
         """Setup test."""
         self.useFixture(base.OpenDaylightRestClientFixture())
+        self.useFixture(base.OpenDaylightPseudoAgentPrePopulateFixture())
         self.useFixture(OpenDaylightAgentDBFixture())
         super(TestPseudoAgentDBBindingWorker, self).setUp()
 
@@ -117,7 +213,7 @@ class TestPseudoAgentDBBindingWorker(base.DietTestCase):
     def test_update_agents_db(self):
         """test agent update."""
         self.worker.update_agents_db(
-            hostconfigs=self.sample_odl_hconfigs['hostconfigs']['hostconfig'])
+            hostconfigs=SAMPLE_ODL_HCONFIGS['hostconfigs']['hostconfig'])
         self.worker.agents_db.create_or_update_agent.assert_called_once()
 
 
@@ -133,6 +229,7 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
         "host": "devstack",      # host-id in ODL JSON
         "agent_type": "ODL L2",  # host-type in ODL JSON
                                  # config in ODL JSON
+        "alive": True,
         "configurations": {"supported_vnic_types": [
             {"vnic_type": "normal", "vif_type": "vhostuser",
              "vif_details": {
@@ -155,18 +252,19 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
         "host": "devstack",      # host-id in ODL JSON
         "agent_type": "ODL L2",  # host-type in ODL JSON
                                  # config in ODL JSON
+        "alive": True,
         "configurations": {"supported_vnic_types": [
             {"vnic_type": "normal", "vif_type": "vhostuser",
              "vif_details": {
                  "uuid": "TEST_UUID",
                  "has_datapath_type_netdev": True,
                  "support_vhost_user": True,
-                 "port_prefix": "vhu_",
+                 "port_prefix": "vhu",
                  "vhostuser_socket_dir": "/var/run/openvswitch",
                  "vhostuser_ovs_plug": True,
                  "vhostuser_mode": "client",
                  "vhostuser_socket":
-                     "/var/run/openvswitch/vhu_$PORT_ID"
+                     "/var/run/openvswitch/vhu$PORT_ID"
              }}],
             "allowed_network_types": [
                 "local", "vlan", "vxlan", "gre"],
@@ -204,6 +302,21 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
         "allowed_network_types": ["local", "vlan", "vxlan", "gre"],
         "bridge_mappings": {"physnet1": "br-ex"}}}
 
+    # Test data for vanilla OVS with SR-IOV offload
+    sample_hconfig_dbget_ovs_sriov_offload = {"configurations": {
+        "supported_vnic_types": [{
+            "vnic_type": "normal",
+            "vif_type": portbindings.VIF_TYPE_OVS,
+            "vif_details": {
+                "some_test_details": None}}, {
+            "vnic_type": "direct",
+            "vif_type": portbindings.VIF_TYPE_OVS,
+            "vif_details": {
+                "some_test_details": None
+            }}, ],
+        "allowed_network_types": ["local", "vlan", "vxlan", "gre"],
+        "bridge_mappings": {"physnet1": "br-ex"}}}
+
     # Test data for OVS-DPDK
     sample_hconfig_dbget_ovs_dpdk = {"configurations": {
         "supported_vnic_types": [{
@@ -213,12 +326,12 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
                 "uuid": "TEST_UUID",
                 "has_datapath_type_netdev": True,
                 "support_vhost_user": True,
-                "port_prefix": "vhu_",
+                "port_prefix": "vhu",
                 # Assumption: /var/run mounted as tmpfs
                 "vhostuser_socket_dir": "/var/run/openvswitch",
                 "vhostuser_ovs_plug": True,
                 "vhostuser_mode": "client",
-                "vhostuser_socket": "/var/run/openvswitch/vhu_$PORT_ID"}}],
+                "vhostuser_socket": "/var/run/openvswitch/vhu$PORT_ID"}}],
         "allowed_network_types": ["local", "vlan", "vxlan", "gre"],
         "bridge_mappings": {"physnet1": "br-ex"}}}
 
@@ -285,23 +398,25 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
 
     # test data valid  and invalid segments
     test_valid_segment = {
-        ml2_api.ID: 'API_ID',
-        ml2_api.NETWORK_TYPE: n_const.TYPE_LOCAL,
-        ml2_api.SEGMENTATION_ID: 'API_SEGMENTATION_ID',
-        ml2_api.PHYSICAL_NETWORK: 'API_PHYSICAL_NETWORK'}
+        api.ID: 'API_ID',
+        api.NETWORK_TYPE: n_const.TYPE_LOCAL,
+        api.SEGMENTATION_ID: 'API_SEGMENTATION_ID',
+        api.PHYSICAL_NETWORK: 'API_PHYSICAL_NETWORK'}
 
     test_invalid_segment = {
-        ml2_api.ID: 'API_ID',
-        ml2_api.NETWORK_TYPE: n_const.TYPE_NONE,
-        ml2_api.SEGMENTATION_ID: 'API_SEGMENTATION_ID',
-        ml2_api.PHYSICAL_NETWORK: 'API_PHYSICAL_NETWORK'}
+        api.ID: 'API_ID',
+        api.NETWORK_TYPE: n_const.TYPE_NONE,
+        api.SEGMENTATION_ID: 'API_SEGMENTATION_ID',
+        api.PHYSICAL_NETWORK: 'API_PHYSICAL_NETWORK'}
 
     def setUp(self):
         """Setup test."""
         self.useFixture(base.OpenDaylightRestClientFixture())
         self.useFixture(base.OpenDaylightFeaturesFixture())
+        self.useFixture(base.OpenDaylightPseudoAgentPrePopulateFixture())
         self.useFixture(OpenDaylightAgentDBFixture())
         super(TestPseudoAgentDBBindingController, self).setUp()
+        self.useFixture(fixture.CallbackRegistryFixture())
 
         self.mgr = pseudo_agentdb_binding.PseudoAgentDBBindingController()
 
@@ -315,7 +430,7 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
             network_type
             for network_type in all_network_types
             if self.mgr._is_valid_segment(
-                {ml2_api.NETWORK_TYPE: network_type},
+                {api.NETWORK_TYPE: network_type},
                 {'allowed_network_types': [
                     n_const.TYPE_LOCAL, n_const.TYPE_GRE,
                     n_const.TYPE_VXLAN, n_const.TYPE_VLAN]})}
@@ -336,7 +451,22 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
             port_context, self.sample_hconfig_dbget_ovs)
 
         port_context.set_binding.assert_called_once_with(
-            self.test_valid_segment[ml2_api.ID], vif_type,
+            self.test_valid_segment[api.ID], vif_type,
+            vif_details, status=n_const.PORT_STATUS_ACTIVE)
+
+    def test_bind_port_with_vif_type_ovs_with_sriov_offload(self):
+        """test bind_port with vanilla ovs with SR-IOV offload"""
+        port_context = self._fake_port_context(
+            fake_segments=[self.test_invalid_segment, self.test_valid_segment])
+
+        vif_type = portbindings.VIF_TYPE_OVS
+        vif_details = {'some_test_details': None}
+
+        self.mgr._hconfig_bind_port(
+            port_context, self.sample_hconfig_dbget_ovs_sriov_offload)
+
+        port_context.set_binding.assert_called_once_with(
+            self.test_valid_segment[api.ID], vif_type,
             vif_details, status=n_const.PORT_STATUS_ACTIVE)
 
     def _set_pass_vif_details(self, port_context, vif_details):
@@ -344,7 +474,7 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
         vhostuser_socket_dir = vif_details.get(
             'vhostuser_socket_dir', '/var/run/openvswitch')
         port_spec = vif_details.get(
-            'port_prefix', 'vhu_') + port_context.current['id']
+            'port_prefix', 'vhu') + port_context.current['id']
         socket_path = os_path.join(vhostuser_socket_dir, port_spec)
         vif_details.update({portbindings.VHOST_USER_SOCKET: socket_path})
 
@@ -364,9 +494,25 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
         self._set_pass_vif_details(port_context, pass_vif_details)
 
         port_context.set_binding.assert_called_once_with(
-            self.test_valid_segment[ml2_api.ID], pass_vif_type,
+            self.test_valid_segment[api.ID], pass_vif_type,
             pass_vif_details, status=n_const.PORT_STATUS_ACTIVE)
 
+    def _test_bind_port_failed_when_agent_dead(self, hconfig):
+        hconfig['alive'] = False
+        port_context = self._fake_port_context(
+            fake_segments=[self.test_invalid_segment, self.test_valid_segment],
+            host_agents=[hconfig])
+        self.mgr.bind_port(port_context)
+        port_context.set_binding.assert_not_called()
+
+    def test_bind_port_failed_when_agent_dead_vpp(self):
+        hconfig = deepcopy(self.sample_hconf_str_tmpl_subs_vpp)
+        self._test_bind_port_failed_when_agent_dead(hconfig)
+
+    def test_bind_port_failed_when_agent_dead_ovs(self):
+        hconfig = deepcopy(self.sample_hconf_str_tmpl_subs_ovs)
+        self._test_bind_port_failed_when_agent_dead(hconfig)
+
     def test_bind_port_with_vif_type_vhost_user_vpp(self):
         """test bind_port with vpp."""
         port_context = self._fake_port_context(
@@ -381,7 +527,7 @@ class TestPseudoAgentDBBindingController(base.DietTestCase):
         self._set_pass_vif_details(port_context, pass_vif_details)
 
         port_context.set_binding.assert_called_once_with(
-            self.test_valid_segment[ml2_api.ID], pass_vif_type,
+            self.test_valid_segment[api.ID], pass_vif_type,
             pass_vif_details, status=n_const.PORT_STATUS_ACTIVE)
 
     def test_bind_port_without_valid_segment(self):
@@ -527,6 +673,7 @@ class TestPseudoAgentDBBindingControllerBug1608659(
 
     def setUp(self):
         self.useFixture(base.OpenDaylightRestClientFixture())
+        self.useFixture(base.OpenDaylightPseudoAgentPrePopulateFixture())
         self.useFixture(OpenDaylightAgentDBFixture())
         super(TestPseudoAgentDBBindingControllerBug1608659, self).setUp(
             plugin='ml2')
@@ -545,12 +692,14 @@ class TestPseudoAgentNeutronWorker(testlib_api.SqlTestCase):
         self.useFixture(base.OpenDaylightRestClientFixture())
         self.useFixture(base.OpenDaylightJournalThreadFixture())
         self.useFixture(base.OpenDaylightFeaturesFixture())
+        self.useFixture(base.OpenDaylightPseudoAgentPrePopulateFixture())
+        self.cfg = self.useFixture(config_fixture.Config())
         self.mock_periodic_thread = mock.patch.object(
             periodic_task.PeriodicTask, 'start').start()
         super(TestPseudoAgentNeutronWorker, self).setUp()
-        cfg.CONF.set_override('mechanism_drivers', ['opendaylight_v2'], 'ml2')
-        cfg.CONF.set_override('port_binding_controller',
-                              'pseudo-agentdb-binding', 'ml2_odl')
+        self.cfg.config(mechanism_drivers=['opendaylight_v2'], group='ml2')
+        self.cfg.config(
+            port_binding_controller='pseudo-agentdb-binding', group='ml2_odl')
 
     def test_get_worker(self):
         workers = ml2_plugin.Ml2Plugin().get_workers()
@@ -566,8 +715,7 @@ class TestPseudoAgentNeutronWorker(testlib_api.SqlTestCase):
         worker.reset()
 
     def test_worker_start_websocket(self):
-        cfg.CONF.set_override('enable_websocket_pseudo_agentdb',
-                              True, 'ml2_odl')
+        self.cfg.config(enable_websocket_pseudo_agentdb=True, group='ml2_odl')
         worker = pseudo_agentdb_binding.PseudoAgentDBBindingWorker()
         with mock.patch.object(
                 websocket_client.OpenDaylightWebsocketClient,
@@ -576,8 +724,7 @@ class TestPseudoAgentNeutronWorker(testlib_api.SqlTestCase):
             mock_odl_create_websocket.assert_called_once()
 
     def test_worker_start_periodic(self):
-        cfg.CONF.set_override('enable_websocket_pseudo_agentdb',
-                              False, 'ml2_odl')
+        self.cfg.config(enable_websocket_pseudo_agentdb=False, group='ml2_odl')
         worker = pseudo_agentdb_binding.PseudoAgentDBBindingWorker()
         with mock.patch.object(
                 periodic_task.PeriodicTask, 'start') as mock_start:
