@@ -14,8 +14,6 @@
 #    under the License.
 from mock import patch
 
-from neutron.db import api as neutron_db_api
-
 from networking_odl.common import constants as odl_const
 from networking_odl.db import db
 from networking_odl.sfc import sfc_driver_v2 as sfc
@@ -28,7 +26,6 @@ class TestOpenDaylightSFCDriverV2(base_v2.OpenDaylightConfigBase):
     def setUp(self):
         self.useFixture(odl_base.OpenDaylightRestClientFixture())
         super(TestOpenDaylightSFCDriverV2, self).setUp()
-        self.db_session = neutron_db_api.get_session()
         self.handler = sfc.OpenDaylightSFCDriverV2()
         self.handler.initialize()
 
@@ -71,16 +68,19 @@ class TestOpenDaylightSFCDriverV2(base_v2.OpenDaylightConfigBase):
                          '%s_%s_%s' % (operation, resource_str, timing))
         method(context)
 
-    def _test_event(self, operation, timing, resource_str, object_type):
+    def _test_event(self, operation, timing, resource_str,
+                    object_type):
         context = self._get_mock_operation_context(object_type)
         self._call_operation_object(operation, timing, resource_str, context)
+        if timing == 'precommit':
+            self.db_session.flush()
         row = db.get_oldest_pending_db_row_with_lock(self.db_session)
 
         if timing == 'precommit':
             self.assertEqual(operation, row['operation'])
             self.assertEqual(object_type, row['object_type'])
         elif timing == 'after':
-            self.assertEqual(None, row)
+            self.assertIsNone(row)
 
     # TODO(yamahata): utilize test scenarios
     def test_create_port_pair_precommit(self):
