@@ -14,48 +14,61 @@
 #  under the License.
 #
 
+from neutron_lib.callbacks import events
+from neutron_lib.callbacks import registry
+from neutron_lib.callbacks import resources
+from neutron_lib import constants as n_const
+from neutron_lib import context
+from neutron_lib.plugins import directory
 from oslo_config import cfg
+from oslo_log import helpers as log_helpers
 from oslo_log import log as logging
 
-from neutron.callbacks import events
-from neutron.callbacks import registry
 from neutron.services.trunk import constants as t_consts
 from neutron.services.trunk.drivers import base as trunk_base
 
-from networking_odl._i18n import _LI
 from networking_odl.common import config as odl_conf
 from networking_odl.common import constants as odl_const
+from networking_odl.journal import full_sync
 from networking_odl.journal import journal
 from networking_odl.trunk import constants as odltrunk_const
 
 LOG = logging.getLogger(__name__)
 
+TRUNK_RESOURCES = {
+    odl_const.ODL_TRUNK: odl_const.ODL_TRUNKS
+}
 
+
+@registry.has_registry_receivers
 class OpenDaylightTrunkHandlerV2(object):
     def __init__(self):
         cfg.CONF.register_opts(odl_conf.odl_opts, "ml2_odl")
-        self.journal = journal.OpendaylightJournalThread()
-        LOG.info(_LI('initialized trunk driver for OpendayLight'))
+        self.journal = journal.OpenDaylightJournalThread()
+        full_sync.register(t_consts.TRUNK, TRUNK_RESOURCES)
+        LOG.info('initialized trunk driver for OpendayLight')
 
     @staticmethod
     def _record_in_journal(context, trunk_id, operation, data):
-        journal.record(context, context, odl_const.ODL_TRUNK,
-                       trunk_id, operation, data)
+        journal.record(context, odl_const.ODL_TRUNK, trunk_id, operation, data)
 
     # TODO(vthapar) Revisit status updates once websockets are fully
     # implemented - https://review.openstack.org/#/c/421127/
+    @log_helpers.log_method_call
     def trunk_create_precommit(self, resource, event, trunk_plugin, payload):
         data = payload.current_trunk.to_dict()
         data['status'] = t_consts.ACTIVE_STATUS
         self._record_in_journal(payload.context, payload.trunk_id,
                                 odl_const.ODL_CREATE, data)
 
+    @log_helpers.log_method_call
     def trunk_update_precommit(self, resource, event, trunk_plugin, payload):
         payload.current_trunk.update(status=t_consts.ACTIVE_STATUS)
         data = payload.current_trunk.to_dict()
         self._record_in_journal(payload.context, payload.trunk_id,
                                 odl_const.ODL_UPDATE, data)
 
+    @log_helpers.log_method_call
     def trunk_delete_precommit(self, resource, event, trunk_plugin, payload):
         # fill in data with parent ids, will be used in parent validations
         trunk_dict = payload.original_trunk.to_dict()
@@ -64,18 +77,64 @@ class OpenDaylightTrunkHandlerV2(object):
         self._record_in_journal(payload.context, payload.trunk_id,
                                 odl_const.ODL_DELETE, data)
 
+    @log_helpers.log_method_call
     def trunk_create_postcommit(self, resource, event, trunk_plugin, payload):
         payload.current_trunk.update(status=t_consts.ACTIVE_STATUS)
         self.journal.set_sync_event()
 
+    @log_helpers.log_method_call
     def trunk_update_postcommit(self, resource, event, trunk_plugin, payload):
         payload.current_trunk.update(status=t_consts.ACTIVE_STATUS)
         self.journal.set_sync_event()
 
+    @log_helpers.log_method_call
     def trunk_delete_postcommit(self, resource, event, trunk_plugin, payload):
         self.journal.set_sync_event()
 
+    @log_helpers.log_method_call
+    def trunk_subports_set_status(self, resource, event, trunk_plugin,
+                                  payload):
+        core_plugin = directory.get_plugin()
+        admin_context = context.get_admin_context()
 
+        if event == events.AFTER_DELETE:
+            status = n_const.PORT_STATUS_DOWN
+        else:
+            parent_id = payload.current_trunk.port_id
+            parent_port = core_plugin._get_port(admin_context, parent_id)
+            status = parent_port['status']
+
+        for subport in payload.subports:
+            self._set_subport_status(core_plugin, admin_context,
+                                     subport.port_id, status)
+
+    @log_helpers.log_method_call
+    def trunk_subports_update_status(self, resource, event, trigger, **kwargs):
+        core_plugin = directory.get_plugin()
+        admin_context = context.get_admin_context()
+        port = kwargs['port']
+        original_port = kwargs['original_port']
+        if port['status'] == original_port['status']:
+            return
+        for subport_id in self._get_subports_ids(port['id']):
+            self._set_subport_status(core_plugin, admin_context, subport_id,
+                                     port['status'])
+
+    def _set_subport_status(self, plugin, admin_context, port_id, status):
+        plugin.update_port_status(admin_context, port_id, status)
+
+    def _get_subports_ids(self, port_id):
+        trunk_plugin = directory.get_plugin('trunk')
+        filters = {'port_id': port_id}
+        trunks = trunk_plugin.get_trunks(context.get_admin_context(),
+                                         filters=filters)
+        if not trunks:
+            return ()
+        trunk = trunks[0]
+        return (subport['port_id'] for subport in trunk['sub_ports'])
+
+
+@registry.has_registry_receivers
 class OpenDaylightTrunkDriverV2(trunk_base.DriverBase):
     @property
     def is_loaded(self):
@@ -85,9 +144,10 @@ class OpenDaylightTrunkDriverV2(trunk_base.DriverBase):
         except cfg.NoSuchOptError:
             return False
 
-    def register(self, resource, event, trigger, **kwargs):
+    @registry.receives(t_consts.TRUNK_PLUGIN, [events.AFTER_INIT])
+    def register(self, resource, event, trigger, payload=None):
         super(OpenDaylightTrunkDriverV2, self).register(
-            resource, event, trigger, **kwargs)
+            resource, event, trigger, payload=payload)
         self._handler = OpenDaylightTrunkHandlerV2()
         registry.subscribe(self._handler.trunk_create_precommit,
                            t_consts.TRUNK, events.PRECOMMIT_CREATE)
@@ -101,12 +161,22 @@ class OpenDaylightTrunkDriverV2(trunk_base.DriverBase):
                            t_consts.TRUNK, events.PRECOMMIT_DELETE)
         registry.subscribe(self._handler.trunk_delete_postcommit,
                            t_consts.TRUNK, events.AFTER_DELETE)
-        for event in (events.PRECOMMIT_CREATE, events.PRECOMMIT_DELETE):
+        for event_ in (events.PRECOMMIT_CREATE, events.PRECOMMIT_DELETE):
             registry.subscribe(self._handler.trunk_update_precommit,
-                               t_consts.SUBPORTS, event)
-        for event in (events.AFTER_CREATE, events.AFTER_DELETE):
+                               t_consts.SUBPORTS, event_)
+        for event_ in (events.AFTER_CREATE, events.AFTER_DELETE):
             registry.subscribe(self._handler.trunk_update_postcommit,
-                               t_consts.SUBPORTS, event)
+                               t_consts.SUBPORTS, event_)
+            # Upon subport creation/deletion we need to set the right port
+            # status:
+            # 1. Set it to parent status when it is attached to the trunk
+            # 2. Set it to down when is removed from the trunk
+            registry.subscribe(self._handler.trunk_subports_set_status,
+                               t_consts.SUBPORTS, event_)
+        # NOTE(ltomasbo): if the status of the parent port changes, the
+        # subports need to update their status too
+        registry.subscribe(self._handler.trunk_subports_update_status,
+                           resources.PORT, events.AFTER_UPDATE)
 
     @classmethod
     def create(cls):
