@@ -82,9 +82,6 @@ function _init {
     DEST=${GATE_DEST:-$DEST}
     STACK_USER=${GATE_STACK_USER:-$STACK_USER}
     REQUIREMENTS_DIR=$DEST/requirements
-    if [[ -n "$SCREEN_LOGDIR" ]]; then
-        mkdir -p $SCREEN_LOGDIR
-    fi
 }
 
 
@@ -93,6 +90,9 @@ function _install_base_deps {
 
     INSTALL_TESTONLY_PACKAGES=True
     PACKAGES=$(get_packages general)
+    # for gethostip command
+    enable_plugin networking-odl https://git.openstack.org/openstack/networking-odl
+    PACKAGES="$PACKAGES $(get_plugin_packages)"
     # Do not install 'python-' prefixed packages other than
     # python-dev*. Networking ODL's functional testing relies on deployment
     # to a tox env so there is no point in installing python
@@ -185,19 +185,23 @@ function _install_opendaylight {
 
     NETWORKING_ODL_DIR=${NETWORKING_ODL_DIR:-$REPO_BASE/networking-odl}
     ODL_V2DRIVER=${ODL_V2DRIVER:-True}
+    Q_USE_PUBLIC_VETH=False
+    ODL_DONT_WAIT_OVS_BR=True
     # openstack service provider isn't needed, only ODL neutron northbound
     # is necessary for functional test
     ODL_NETVIRT_KARAF_FEATURE=odl-neutron-service,odl-restconf-all,odl-aaa-authn,odl-dlux-core,odl-mdsal-apidocs,odl-neutron-logger
+    ODL_BOOT_WAIT_URL=controller/nb/v2/neutron/networks
     if [[ "$VENV" =~ "dsvm-fullstack" ]]; then
+        ODL_BOOT_WAIT_URL=restconf/operational/network-topology:network-topology/topology/netvirt:1
         export ODL_NETVIRT_KARAF_FEATURE=odl-neutron-service,odl-restconf-all,odl-aaa-authn,odl-dlux-core,odl-mdsal-apidocs,odl-netvirt-openstack,odl-neutron-logger
     fi
-    ODL_BOOT_WAIT_URL=controller/nb/v2/neutron/networks
     source $NETWORKING_ODL_DIR/devstack/settings.odl
 
+    local ODL_NEUTRON_NETWORK_WAIT_URL=controller/nb/v2/neutron/networks
     set +e
     curl -o /dev/null --fail --silent --head -u \
          ${ODL_USERNAME}:${ODL_PASSWORD} \
-         http://${ODL_MGR_HOST}:${ODL_PORT}/${ODL_BOOT_WAIT_URL}
+         http://${ODL_MGR_HOST}:${ODL_PORT}/${ODL_NEUTRON_NETWORK_WAIT_URL}
     local result=$?
     set -e
     if [ $result -eq 0 ]; then
@@ -205,16 +209,6 @@ function _install_opendaylight {
         return 0
     fi
 
-    # start_odl tries to run under screen session. ensure screen is running
-    USE_SCREEN=$(trueorfalse True USE_SCREEN)
-    if [[ "$USE_SCREEN" == "True" ]]; then
-        # Create a new named screen to run processes in
-        if ! (etype -p screen > /dev/null && screen -ls | egrep -q "[0-9]\.$SCREEN_NAME"); then
-            screen -d -m -S $SCREEN_NAME -t shell -s /bin/bash
-            sleep 1
-        fi
-    fi
-
     enable_service odl-server
     if [[ "$VENV" =~ "fullstack" ]]; then
         enable_service odl-compute
@@ -224,13 +218,23 @@ function _install_opendaylight {
     fi
     source $NETWORKING_ODL_DIR/devstack/plugin.sh stack install
     source $NETWORKING_ODL_DIR/devstack/plugin.sh stack post-config
+
+    $BASE/new/opendaylight/*karaf-*/bin/client "feature:list -i"
 }
 
 
 function _install_post_devstack {
     echo_summary "Performing post-devstack installation"
 
-    _install_databases
+    if [[ "$VENV" =~ "dsvm-fullstack" ]]; then
+        # NOTE(yamahata):
+        # fullstack can use sqlite. not db server is needed in theory.
+        # _install_databases nopg
+        echo "don't install databases"
+    else
+        _install_databases
+    fi
+
     # networkign-odl devstack plugin requires infra
     _install_infra
     _install_opendaylight
@@ -238,8 +242,10 @@ function _install_post_devstack {
     if is_ubuntu; then
         install_package isc-dhcp-client
         install_package netcat-openbsd
+        install_package iputils-arping  # needed fullstack arping test
     elif is_fedora; then
         install_package dhclient
+        install_package arping  # needed fullstack arping test
     else
         exit_distro_not_supported "installing dhclient package"
     fi
